unofficial mirror of bug-gnu-emacs@gnu.org 
 help / color / mirror / code / Atom feed
* bug#30812: Perl syntax highlighting regression in fix for #27613? (feecb66b6fe41c977b8e11b5f2d419c9544f42de)
@ 2018-03-13 23:14 Clément Pit-Claudel
  2018-03-21  0:26 ` Noam Postavsky
  0 siblings, 1 reply; 4+ messages in thread
From: Clément Pit-Claudel @ 2018-03-13 23:14 UTC (permalink / raw)
  To: 30812; +Cc: jeffersoncarpenter2


[-- Attachment #1.1: Type: text/plain, Size: 820 bytes --]

X-Debbugs-CC: jeffersoncarpenter2@gmail.com

Hi all,

I think the following commit was a bit too enthusiastic, as variables like @temp are now highlighted in font-lock-type-face.

diff --git a/lisp/progmodes/perl-mode.el b/lisp/progmodes/perl-mode.el
--- a/lisp/progmodes/perl-mode.el
+++ b/lisp/progmodes/perl-mode.el
@@ -181,4 +181,5 @@
      ;;
-     ;; Fontify local and my keywords as types.
-     ("\\<\\(local\\|my\\)\\>" . font-lock-type-face)
+     ;; Fontify declarators and prefixes as types.
+     ("\\<\\(anon\\|argument\\|has\\|local\\|my\\|our\\|state\\|supersede\\)\\>" . font-lock-type-face) ; declarators
+     ("\\<\\(let\\|temp\\)\\>" . font-lock-type-face) ; prefixes
      ;;

Am I missing something? (I don't speak Perl, so I noticed this in a regression test)

Clément.



[-- Attachment #2: OpenPGP digital signature --]
[-- Type: application/pgp-signature, Size: 819 bytes --]

^ permalink raw reply	[flat|nested] 4+ messages in thread

end of thread, other threads:[~2020-08-22 16:03 UTC | newest]

Thread overview: 4+ messages (download: mbox.gz follow: Atom feed
-- links below jump to the message on this page --
2018-03-13 23:14 bug#30812: Perl syntax highlighting regression in fix for #27613? (feecb66b6fe41c977b8e11b5f2d419c9544f42de) Clément Pit-Claudel
2018-03-21  0:26 ` Noam Postavsky
2018-03-21  4:21   ` Clément Pit-Claudel
2020-08-22 16:03   ` Lars Ingebrigtsen

Code repositories for project(s) associated with this public inbox

	https://git.savannah.gnu.org/cgit/emacs.git

This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox;
as well as URLs for read-only IMAP folder(s) and NNTP newsgroup(s).